@@ -1,11 +1,11 @@
 /*
- * "$Id: ippfind.c 12139 2014-08-29 17:50:38Z msweet $"
+ * "$Id: ippfind.c 12465 2015-02-01 02:47:23Z msweet $"
  *
  * Utility to find IPP printers via Bonjour/DNS-SD and optionally run
  * commands such as IPP and Bonjour conformance tests.  This tool is
  * inspired by the UNIX "find" command, thus its name.
  *
- * Copyright 2008-2014 by Apple Inc.
+ * Copyright 2008-2015 by Apple Inc.
  *
  * These coded instructions, statements, and computer programs are the
  * property of Apple Inc. and are protected by Federal copyright
@@ -2564,6 +2564,10 @@ resolve_callback(
   service->host        = strdup(hostTarget);
   service->port        = ntohs(port);
 
+  value = service->host + strlen(service->host) - 1;
+  if (value >= service->host && *value == '.')
+    *value = '\0';
+
  /*
   * Loop through the TXT key/value pairs and add them to an array...
   */
@@ -2635,6 +2639,10 @@ resolve_callback(
   service->host        = strdup(hostTarget);
   service->port        = port;
 
+  value = service->host + strlen(service->host) - 1;
+  if (value >= service->host && *value == '.')
+    *value = '\0';
+
  /*
   * Loop through the TXT key/value pairs and add them to an array...
   */
@@ -2835,5 +2843,5 @@ show_version(void)
 
 
 /*
- * End of "$Id: ippfind.c 12139 2014-08-29 17:50:38Z msweet $".
+ * End of "$Id: ippfind.c 12465 2015-02-01 02:47:23Z msweet $".
  */
